@@ -9,8 +9,8 @@ import pandas as pd
 
 def date_diff(
         series: pd.Series,
-        epoch: Union[str, datetime.datetime, np.datetime64],
-        amount: int =1,
+        epoch: Union[str, datetime.datetime, np.datetime64, pd.Series],
+        amount: int = 1,
         unit: str = 'D',
         dtype: str = 'float'
 ):
@@ -32,7 +32,10 @@ def date_diff(
     # Transform epoch into a datetime64
     if isinstance(epoch, str):
         epoch = parse(epoch)
-    epoch = np.datetime64(epoch)
+    elif isinstance(epoch, pd.Series):
+        epoch = epoch.astype(np.datetime64)
+    else:
+        epoch = np.datetime64(epoch)
 
     # Return a series of numerical differences
     return ((series - epoch) / np.timedelta64(amount, unit)).astype(dtype)
@@ -47,8 +50,10 @@ def slugify(vals: Union[str, List[str]], sep: str = '_'):
         vals = [vals]
     else:
         str_input = False
-    out = [re.sub(r'[^A-Za-z0-9]+', sep, v).lower() for v in vals]
+    out = [re.sub(r'[^A-Za-z0-9]+', sep, v.strip()).lower() for v in vals]
     out = [re.sub(r'_{2:}', sep, v) for v in out]
+    out = [re.sub(r'^_', '', v) for v in out]
+    out = [re.sub(r'_$', '', v) for v in out]
 
     if str_input:
         return out[0]
